@@ -1,8 +1,8 @@
-# Copyright (c) 2012 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2009 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Frame.pm,v 1.17 2011/01/23 12:26:24 gavin Exp $
+# $Id: Frame.pm,v 1.17 2008/01/23 12:26:24 gavin Exp $
 package Net::EPP::Frame;
 use Carp;
 use Net::EPP::Frame::Command;
@@ -177,6 +177,8 @@ sub new {
 	bless($self, $package);
 
 	my $epp = $self->createElementNS($EPP_URN, 'epp');
+	$epp->setNamespace($SCHEMA_URI, 'xsi', 0);
+	$epp->setAttributeNS($SCHEMA_URI, 'schemaLocation', "$EPP_URN epp-1.0.xsd");
 	$self->addChild($epp);
 
 	my $el = $self->createElement($type);
@@ -310,7 +312,7 @@ CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2012 CentralNic Ltd. This module is free software; you can
+This module is (c) 2007 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
