@@ -1,4 +1,4 @@
-# Copyright (c) 2012 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2009 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
@@ -20,7 +20,7 @@ for domain objects.
 	use Net::EPP::Frame::Command::Create::Domain;
 	use strict;
 
-	my $create = Net::EPP::Frame::Command::Create::Domain->new;
+	my $check = Net::EPP::Frame::Command::Create::Domain->new;
 	$create->setDomain('example.uk.com);
 
 	print $create->toString(1);
@@ -126,83 +126,25 @@ sub setContacts {
 	return 1;
 }
 
-# 
-# Type of elements of @ns depends on NS model used by EPP server.
-#   hostObj model:
-#       each element is a name of NS host object
-#   hostAttr model:
-#       each element is a hashref:
-#       {
-#           name => 'ns1.example.com,
-#           addrs => [
-#               { version => 'v4', addr => '192.168.0.10', },
-#               { version => 'v4', addr => '192.168.0.20', },
-#               ...
-#           ];
-#        }
-#
 sub setNS {
 	my ($self, @ns) = @_;
 
-
-        if ( ref $ns[0] eq 'HASH' ) {
-            $self->addHostAttrNS(@ns);
-        }
-        else {
-            $self->addHostObjNS(@ns);
-        }
-
-	return 1;
-}
-
-sub addHostAttrNS {
-        my ($self, @ns) = @_;
-
-        my $ns = $self->createElement('domain:ns');
-
-        # Adding attributes
-        foreach my $host (@ns) {
-                my $hostAttr = $self->createElement('domain:hostAttr');
-
-                # Adding NS name
-                my $hostName = $self->createElement('domain:hostName');
-                $hostName->appendText( $host->{name} );
-                $hostAttr->appendChild($hostName);
-
-                # Adding IP addresses
-                if ( exists $host->{addrs} && ref $host->{addrs} eq 'ARRAY' ) {
-                        foreach my $addr ( @{ $host->{addrs} } ) {
-                                my $hostAddr = $self->createElement('domain:hostAddr');
-                                $hostAddr->appendText( $addr->{addr} );
-                                $hostAddr->setAttribute( ip => $addr->{version} );
-                                $hostAttr->appendChild($hostAddr);
-                        }
-                }
-
-                # Adding host info to frame
-                $ns->appendChild($hostAttr);
-        }
-	$self->getNode('create')->getChildNodes->shift->appendChild($ns);
-        return 1;
-}
-
-sub addHostObjNS {
-        my ($self, @ns) = @_;
-
 	my $ns = $self->createElement('domain:ns');
+
 	foreach my $host (@ns) {
-                my $el = $self->createElement('domain:hostObj');
+		my $el = $self->createElement('domain:hostObj');
 		$el->appendText($host);
 		$ns->appendChild($el);
 	}
 	$self->getNode('create')->getChildNodes->shift->appendChild($ns);
-        return 1;
+
+	return 1;
 }
 
 sub setAuthInfo {
 	my ($self, $authInfo) = @_;
 	my $el = $self->addEl('authInfo');
-	my $pw = $self->createElement('domain:pw');
+	my $pw = $self->createElement('pw');
 	$pw->appendText($authInfo);
 	$el->appendChild($pw);
 	return $el;
@@ -233,7 +175,7 @@ CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2012 CentralNic Ltd. This module is free software; you can
+This module is (c) 2007 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
