@@ -1,8 +1,8 @@
-# Copyright (c) 2012 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2009 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Login.pm,v 1.5 2011/12/03 11:44:52 gavin Exp $
+# $Id: Login.pm,v 1.5 2007/12/03 11:44:52 gavin Exp $
 package Net::EPP::Frame::Command::Login;
 use base qw(Net::EPP::Frame::Command);
 use strict;
@@ -50,11 +50,6 @@ C<E<lt>clIDE<gt>> element.
 This method returns the L<XML::LibXML::Element> object corresponding to the
 C<E<lt>pwE<gt>> element.
 
-	my $node = $frame->newPW;
-
-This method returns the L<XML::LibXML::Element> object corresponding to the
-C<E<lt>newPWE<gt>> element.
-
 	my $node = $frame->svcs;
 
 This method returns the L<XML::LibXML::Element> object corresponding to the
@@ -79,7 +74,6 @@ C<E<lt>langE<gt>> element.
 
 sub clID { $_[0]->getNode('clID') }
 sub pw { $_[0]->getNode('pw') }
-sub newPW { $_[0]->getNode('newPW') }
 sub svcs { $_[0]->getNode('svcs') }
 sub options { $_[0]->getNode('options') }
 sub version { $_[0]->getNode('version') }
@@ -93,7 +87,7 @@ CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2012 CentralNic Ltd. This module is free software; you can
+This module is (c) 2007 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
